PyXMake Developer Guide: PyXMake.Build.Make.CCxx Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.CCxx Class Reference

Base class for all C/C++ build events inherited from Make. More...

Inheritance diagram for PyXMake.Build.Make.CCxx:

## Public Member Functions
def | __init__ (self, args, kwargs)
def | OutputPath (self, libpath=os.getcwd())
def | Build (self, cmdstring)
def | create (self)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| MakeObjectKind
| String identifier of current instance. More...
| exe
| The executable command used in the main build event. More...
| isStatic
| Static or dynamic link library flag. More...
| incremental
| Define if the input should be compiled exactly as provided. More...
| libname
| Name of library, assembled using BuildID. More...
| buildname
| Temporary build name. More...
| linkedIn
| List of libraries which should be statically linked in. More...
| temps
| Blank version of tuple to store temporary file names scheduled for removal. More...
| libdirs
| Blank version of list containing library directories without initially specifying MKL. More...
| outlibs
| Output path for library files. More...
| compargs
| Used defined command line options. More...
| makecmd
| Intel Compiler command. More...
| linkcmd
| Intel Linker command. More...
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all C/C++ build events inherited from Make.

    Inherited class to build projects using Intel C/C++.

Definition at line 505 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.CCxx.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of C/C++ class object.

Definition at line 509 of file Make.py.

## Member Function Documentation

## ◆ Build()

def PyXMake.Build.Make.CCxx.Build | ( |  | self,
|  |  | cmdstring
| ) |  |

    Assemble command strings for the main build event.

Definition at line 562 of file Make.py.

## ◆ create()

def PyXMake.Build.Make.CCxx.create | ( |  | self | ) |

    Execute make command

Definition at line 595 of file Make.py.

## ◆ OutputPath()

def PyXMake.Build.Make.CCxx.OutputPath | ( |  | self,
|  |  | libpath = `os.getcwd()`
| ) |  |

    Define output directories for modules and libraries.

Definition at line 554 of file Make.py.

## Member Data Documentation

## ◆ buildname

PyXMake.Build.Make.CCxx.buildname

Temporary build name.

Definition at line 536 of file Make.py.

## ◆ compargs

PyXMake.Build.Make.CCxx.compargs

Used defined command line options.

Definition at line 584 of file Make.py.

## ◆ exe

PyXMake.Build.Make.CCxx.exe

The executable command used in the main build event.

Definition at line 518 of file Make.py.

## ◆ incremental

PyXMake.Build.Make.CCxx.incremental

Define if the input should be compiled exactly as provided.

Defaults to False, meaning that merging & pre-processing utilities will be carried out.

Definition at line 525 of file Make.py.

## ◆ isStatic

PyXMake.Build.Make.CCxx.isStatic

Static or dynamic link library flag.

Definition at line 521 of file Make.py.

## ◆ libdirs

PyXMake.Build.Make.CCxx.libdirs

Blank version of list containing library directories without initially specifying MKL.

Definition at line 548 of file Make.py.

## ◆ libname

PyXMake.Build.Make.CCxx.libname

Name of library, assembled using BuildID.

Definition at line 534 of file Make.py.

## ◆ linkcmd

PyXMake.Build.Make.CCxx.linkcmd

Intel Linker command.

Definition at line 589 of file Make.py.

## ◆ linkedIn

PyXMake.Build.Make.CCxx.linkedIn

List of libraries which should be statically linked in.

Definition at line 540 of file Make.py.

## ◆ makecmd

PyXMake.Build.Make.CCxx.makecmd

Intel Compiler command.

Definition at line 586 of file Make.py.

## ◆ MakeObjectKind

PyXMake.Build.Make.CCxx.MakeObjectKind

String identifier of current instance.

Definition at line 515 of file Make.py.

## ◆ outlibs

PyXMake.Build.Make.CCxx.outlibs

Output path for library files.

Definition at line 559 of file Make.py.

## ◆ temps

PyXMake.Build.Make.CCxx.temps

Blank version of tuple to store temporary file names scheduled for removal.

Definition at line 544 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py